<template>
  <Inner>
    <template>
      <div v-if="page_content != null">
        <div class="container">
          <div class="row">
            <div class="col-sm-12 pt-0">
              <div class="inner-banner banner_with_spacing">
                <div class="banner_img"><img src="/front-end/images/cat_img.jpg"></div>
                <div class="banner_top_mask"><img src="/front-end/images/inner-banner.png"></div>
                <div class="banner_main_cont">
                  <h1 class="h1">{{ page_content.title }}</h1>
                  <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                      <li class="breadcrumb-item"><a href="/">Home</a></li>
                      <li>{{ page_content.title }}
                      </li>
                    </ol>
                  </nav>
                </div>
              </div>
            </div>
          </div>
        </div>
        <div v-html="page_content.content"></div>
      </div>

    </template>
  </Inner>
</template>
<script>
import Inner from '~/layouts/inner.vue'
import options from '~/assets/options';
export default {
  components: { Inner },
  async asyncData({ $axios, params, store,error }) {
    if(!store.state.front_end_data.url_available) {
      return error({ statusCode: 404, message: 'Page Not Found' })
    }
    else {
      let current_host = store.state.front_end_data.domain_id;
      const data = await $axios.$get(`/api/page-detail/${params.cms}/${current_host}`);
      if (data.error) {
        return { page_content: null };
      }
      return { page_content: data };
    }
  },
  data() {
    return {
      domain: this.$store.state.front_end_data.domain,
    }
  },
  head() {
    if (this.page_content != null) {
      return {
        title: `${this.page_content.meta_title} - ${this.domain.name}`,
        script: [
          {
            src: '/front-end/js/google-analytics.js'
          }
        ],
        meta: [
          {
            hid: 'description',
            name: 'description',
            content: `${this.page_content.meta_description}`
          },
          {
            hid: 'og:title',
            name: 'og:title',
            content: `${this.page_content.meta_title}`
          },
          {
            hid: 'og:description',
            name: 'og:description',
            content: `${this.page_content.meta_description}`
          }, {
            hid: 'og:type',
            name: 'og:type',
            content: "Website"
          },
          {
            hid: 'og:url',
            name: 'og:url',
            content: this.domain.url + this.$route.fullPath
          },
          {
            hid: 'og:url',
            name: 'og:site_name',
            content: this.domain.name
          },
          {
            hid: 'og:image',
            name: 'og:image',
            content: "/images/logo.png"
          },
          {
            hid: 'name',
            name: 'twitter:card',
            content: "summary_large_image"
          },
          {
            hid: 'name',
            name: 'twitter:title',
            content: `${this.page_content.meta_title}`
          },
          {
            hid: 'name',
            name: 'twitter:description',
            content: `${this.page_content.meta_description}`
          },
          {
            hid: 'name',
            name: 'twitter:image:src',
            content: "/images/logo.png"
          },
          {
            hid: 'name',
            name: 'twitter:site',
            content: this.domain.name
          },
        ],
      }
    }
    // else {
    //   return {
    //     title: `404 Page not found - ${this.domain.name}`,
    //   }
    // }
  },
}
</script>

